@@ -313,7 +313,6 @@ class MessageDialog(Dialog):
                 text = MessageCatalog.translate(text)
 
             btn = ttk.Button(frame, bootstyle=bootstyle, text=text)
-            btn.bind("<Return>", lambda _: btn.invoke())
             btn.configure(command=lambda b=btn: self.on_button_press(b))
             btn.pack(padx=2, side=RIGHT)
             btn.lower()  # set focus traversal left-to-right
@@ -1156,7 +1155,7 @@ class Messagebox:
     and alert options."""
 
     @staticmethod
-    def show_info(message, title=" ", parent=None, **kwargs):
+    def show_info(message, title=" ", parent=None, alert=False, **kwargs):
         """Display a modal dialog box with an OK button and an INFO
         icon.
 
@@ -1176,12 +1175,16 @@ class Messagebox:
                 Makes the window the logical parent of the message box. The
                 message box is displayed on top of its parent window.
 
+            alert (bool):
+                Specified whether to ring the display bell.
+
             **kwargs (Dict):
                 Other optional keyword arguments.
         """
         dialog = MessageDialog(
             message=message,
             title=title,
+            alert=alert,
             parent=parent,
             buttons=["OK:primary"],
             icon=Icon.info,
@@ -1194,7 +1197,7 @@ class Messagebox:
         dialog.show(position)
 
     @staticmethod
-    def show_warning(message, title=" ", parent=None, **kwargs):
+    def show_warning(message, title=" ", parent=None, alert=True, **kwargs):
         """Display a modal dialog box with an OK button and a
         warning icon. Also will ring the display bell.
 
@@ -1214,6 +1217,9 @@ class Messagebox:
                 Makes the window the logical parent of the message box. The
                 message box is displayed on top of its parent window.
 
+            alert (bool):
+                Specified whether to ring the display bell.
+
             **kwargs (Dict):
                 Other optional keyword arguments.
         """
@@ -1223,7 +1229,7 @@ class Messagebox:
             parent=parent,
             buttons=["OK:primary"],
             icon=Icon.warning,
-            alert=True,
+            alert=alert,
             localize=True,
             **kwargs,
         )
@@ -1234,7 +1240,7 @@ class Messagebox:
         dialog.show(position)
 
     @staticmethod
-    def show_error(message, title=" ", parent=None, **kwargs):
+    def show_error(message, title=" ", parent=None, alert=True, **kwargs):
         """Display a modal dialog box with an OK button and an
         error icon. Also will ring the display bell.
 
@@ -1254,6 +1260,9 @@ class Messagebox:
                 Makes the window the logical parent of the message box. The
                 message box is displayed on top of its parent window.
 
+            alert (bool):
+                Specified whether to ring the display bell.
+
             **kwargs (Dict):
                 Other optional keyword arguments.
         """
@@ -1263,7 +1272,7 @@ class Messagebox:
             parent=parent,
             buttons=["OK:primary"],
             icon=Icon.error,
-            alert=True,
+            alert=alert,
             localize=True,
             **kwargs,
         )
@@ -1279,6 +1288,7 @@ class Messagebox:
         title=" ",
         parent=None,
         buttons=["No:secondary", "Yes:primary"],
+        alert=True,
         **kwargs,
     ):
         """Display a modal dialog box with yes, no buttons and a
@@ -1311,6 +1321,9 @@ class Messagebox:
                 the style is set to 'primary' by default.
                 `['Yes:success','No:danger']`.
 
+            alert (bool):
+                Specified whether to ring the display bell.
+
             **kwargs (Dict):
                 Other optional keyword arguments.
 
@@ -1326,7 +1339,7 @@ class Messagebox:
             parent=parent,
             buttons=buttons,
             icon=Icon.question,
-            alert=True,
+            alert=alert,
             localize=True,
             **kwargs,
         )
